@@ -26,11 +26,11 @@ to OpenGuides developers.
 
 =head1 SYNOPSIS
 
-  use Config::Tiny;
+  use OpenGuides::Config;
   use OpenGuides::Utils;
   use OpenGuides::Template;
 
-  my $config = Config::Tiny->read('wiki.conf');
+  my $config = OpenGuides::Config->new( file => "wiki.conf" );
   my $wiki = OpenGuides::Utils->make_wiki_object( config => $config );
 
   print OpenGuides::Template->output( wiki     => $wiki,
@@ -107,20 +107,16 @@ sub output {
     my ($class, %args) = @_;
     croak "No template supplied" unless $args{template};
     my $config = $args{config} or croak "No config supplied";
-    my $template_path = $config->{_}->{template_path};
-    my $custom_template_path = $config->{_}->{custom_template_path} || "";
+    my $template_path = $config->template_path;
+    my $custom_template_path = $config->custom_template_path || "";
     my $tt = Template->new( { INCLUDE_PATH => "$custom_template_path:$template_path" } );
 
-    my $script_name = $config->{_}->{script_name};
-    my $script_url  = $config->{_}->{script_url};
-
-    # Ensure that script_url ends in a '/' - this is done in Build.PL but
-    # we need to allow for people editing the config file by hand later.
-    $script_url .= "/" unless $script_url =~ /\/$/;
+    my $script_name = $config->script_name;
+    my $script_url  = $config->script_url;
 
     # Check cookie to see if we need to set the formatting_rules_link.
     my ($formatting_rules_link, $omit_help_links);
-    my $formatting_rules_node = $config->{_}->{formatting_rules_node} ||"";
+    my $formatting_rules_node = $config->formatting_rules_node ||"";
     my %cookie_data = OpenGuides::CGI->get_prefs_from_cookie(config=>$config);
     if ( $cookie_data{omit_help_links} ) {
         $omit_help_links = 1;
@@ -132,27 +128,27 @@ sub output {
     }
 
     my $enable_page_deletion = 0;
-    if ( $config->{_}->{enable_page_deletion}
-         and ( lc($config->{_}->{enable_page_deletion}) eq "y"
-               or $config->{_}->{enable_page_deletion} eq "1" )
+    if ( $config->enable_page_deletion
+         and ( lc($config->enable_page_deletion) eq "y"
+               or $config->enable_page_deletion eq "1" )
        ) {
         $enable_page_deletion = 1;
     }
 
-    my $tt_vars = { site_name             => $config->{_}->{site_name},
+    my $tt_vars = { site_name             => $config->site_name,
 	   	    cgi_url               => $script_name,
 		    full_cgi_url          => $script_url . $script_name,
-		    contact_email         => $config->{_}->{contact_email},
-		    stylesheet            => $config->{_}->{stylesheet_url},
+		    contact_email         => $config->contact_email,
+		    stylesheet            => $config->stylesheet_url,
 		    home_link             => $script_url . $script_name,
-		    home_name             => $config->{_}->{home_name},
-                    navbar_on_home_page   => $config->{_}->{navbar_on_home_page},
+		    home_name             => $config->home_name,
+                    navbar_on_home_page   => $config->navbar_on_home_page,
                     omit_help_links       => $omit_help_links,
                     formatting_rules_link => $formatting_rules_link,
                     formatting_rules_node => $formatting_rules_node,
                     openguides_version    => $OpenGuides::VERSION,
                     enable_page_deletion  => $enable_page_deletion,
-                    language              => $config->{_}->{default_language},
+                    language              => $config->default_language,
     };
 
     if ($args{node}) {
@@ -236,7 +232,7 @@ sub extract_metadata_vars {
     my $q = $args{cgi_obj};
     my $formatter = $args{wiki}->formatter;
     my $config = $args{config};
-    my $script_name = $config->{_}->{script_name};
+    my $script_name = $config->script_name;
 
     # Categories and locales are displayed as links in the page footer.
     # We return these twice, as eg 'category' being a simple array of
@@ -249,8 +245,10 @@ sub extract_metadata_vars {
     } else {
 	my $categories_text = $q->param('categories');
 	my $locales_text    = $q->param('locales');
-	@catlist = sort split("\r\n", $categories_text);
-	@loclist = sort split("\r\n", $locales_text);
+	@catlist = sort map { s/^\s+//; s/\s+$//; $_; } # trim lead/trail space
+                        split("\r\n", $categories_text);
+	@loclist = sort map { s/^\s+//; s/\s+$//; $_; } # trim lead/trail space
+                        split("\r\n", $locales_text);
     }
 
     my @categories = map { { name => $_,
@@ -289,7 +287,7 @@ sub extract_metadata_vars {
             $vars{$var} = $metadata{$var}[0];
         }
         # Data for the distance search forms on the node display.
-        my $geo_handler = $config->{_}{geo_handler} || 1;
+        my $geo_handler = $config->geo_handler;
         if ( $geo_handler == 1 ) {
             %vars = (
                       %vars,
@@ -329,7 +327,7 @@ sub extract_metadata_vars {
             $vars{$var} = $q->param($var);
         }
 
-        my $geo_handler = $config->{_}{geo_handler};
+        my $geo_handler = $config->geo_handler;
         if ( $geo_handler == 1 ) {
 	    require Geography::NationalGrid::GB;
    	    my $os_x   = $q->param("os_x");
@@ -340,8 +338,8 @@ sub extract_metadata_vars {
             # Trim whitespace - trailing whitespace buggers up the
             # integerification by postgres and it's an easy mistake to
             # make when typing into a form.
-            $os_x =~ s/\s+//;
-            $os_y =~ s/\s+//;
+            $os_x =~ s/\s+//g;
+            $os_y =~ s/\s+//g;
 
 	    # If we were sent x and y, work out lat/long; and vice versa.
   	    if ( $os_x && $os_y ) {
@@ -383,11 +381,9 @@ sub extract_metadata_vars {
 	    my $lat    = $q->param("latitude");
 	    my $long   = $q->param("longitude");
 
-            # Trim whitespace - trailing whitespace buggers up the
-            # integerification by postgres and it's an easy mistake to
-            # make when typing into a form.
-            $osie_x =~ s/\s+//;
-            $osie_y =~ s/\s+//;
+            # Trim whitespace.
+            $osie_x =~ s/\s+//g;
+            $osie_y =~ s/\s+//g;
 
 	    # If we were sent x and y, work out lat/long; and vice versa.
   	    if ( $osie_x && $osie_y ) {
@@ -427,8 +423,11 @@ sub extract_metadata_vars {
 	    my $lat    = $q->param("latitude");
 	    my $long   = $q->param("longitude");
             if ( $lat && $long ) {
+                # Trim whitespace.
+                $lat =~ s/\s+//g;
+                $long =~ s/\s+//g;
                 my ($zone, $easting, $northing) =
-                 Geo::Coordinates::UTM::latlon_to_utm( $config->{_}{ellipsoid},
+                 Geo::Coordinates::UTM::latlon_to_utm( $config->ellipsoid,
                                                        $lat, $long );
                 $easting  =~ s/\..*//; # chop off decimal places
                 $northing =~ s/\..*//; # - metre accuracy enough
@@ -490,7 +489,7 @@ The OpenGuides Project (openguides-dev@openguides.org)
 
 =head1 COPYRIGHT
 
-  Copyright (C) 2003 The OpenGuides Project.  All Rights Reserved.
+  Copyright (C) 2003-2004 The OpenGuides Project.  All Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
